==> hubzero-cms-1.2.2_1.2.2.1.orig.tar.gz: hubzero-cms-1.2.2-1.2.2.1/cms/components/com_wiki/views/comments/tmpl/_list.php <==
<?php
/**
 * @package		HUBzero CMS
 * @author		Shawn Rice <zooley@purdue.edu>
 * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
 *
 * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License,
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');
?>
<ol class="comments" id="t<?php echo (isset($this->parent) ? $this->parent : '0'); ?>">
<?php
if ($this->comments instanceof \Hubzero\Base\ItemList) 
{ 
	$cls = 'odd';
	if (isset($this->cls))
	{
		$cls = ($this->cls == 'odd') ? 'even' : 'odd';
	}

	$this->depth++;

	foreach ($this->comments as $comment) 
	{
		$comment->set('pageid', $this->page->get('id'));

		$view = new JView(
			array(
				'base_path' => JPATH_ROOT . '/components/com_wiki',
				'name'      => 'comments',
				'layout'    => '_comment'
			)
		);
		$view->option     = $this->option;
		$view->comment    = $comment;
		$view->config     = $this->config;
		$view->depth      = $this->depth;
		$view->page       = $this->page;
		$view->version    = $this->version;
		$view->cls        = $cls;
		$view->display();
	}
} 
?>
</ol>

==> hubzero-cms-1.3.1_1.3.1.0.orig.tar.gz: hubzero-cms-1.3.1-1.3.1.0/cms/components/com_wiki/views/comments/tmpl/_list.php <==
<?php
/**
 * @package		HUBzero CMS
 * @author		Shawn Rice <zooley@purdue.edu>
 * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
 *
 * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License,
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');
?>
<ol class="comments" id="t<?php echo (isset($this->parent) ? $this->parent : '0'); ?>">
<?php
if ($this->comments instanceof \Hubzero\Base\ItemList)
{
	$cls = 'odd';
	if (isset($this->cls))
	{
		$cls = ($this->cls == 'odd') ? 'even' : 'odd';
	}

	$this->depth++;

	foreach ($this->comments as $comment)
	{
		$comment->set('pageid', $this->page->get('id'));

		$this->view('_comment', 'comments')
		     ->setBasePath(JPATH_ROOT . '/components/com_wiki')
		     ->set('option', $this->option)
		     ->set('comment', $comment)
		     ->set('config', $this->config)
		     ->set('depth', $this->depth)
		     ->set('page', $this->page)
		     ->set('version', $this->version)
		     ->set('cls', $cls)
		     ->display();
	}
}
?>
</ol>
